@@ -1,5 +1,5 @@
 /*
- * $Id: uptime.c,v 1.32 2004/06/14 01:14:07 wcc Exp $
+ * $Id: uptime.c,v 1.35 2006-03-28 02:35:51 wcc Exp $
  *
  * This module reports uptime information about your bot to http://uptime.eggheads.org. The
  * purpose for this is to see how your bot rates against many others (including EnergyMechs
@@ -13,7 +13,7 @@
  */
 /*
  * Copyright (C) 2001 proton
- * Copyright (C) 2001, 2002, 2003, 2004 Eggheads Development Team
+ * Copyright (C) 2001 - 2006 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -72,7 +72,7 @@ static int hours = 0;
 static int uptimesock;
 static int uptimecount;
 static unsigned long uptimeip;
-static char uptime_version[50] = "";
+static char uptime_version[48] = "";
 
 static int uptime_expmem()
 {
@@ -114,7 +114,7 @@ unsigned long get_ip()
 int init_uptime(void)
 {
   struct sockaddr_in sai;
-  char temp[50] = "";
+  char x[64], *z = x;
 
   upPack.regnr = 0;  /* unused */
   upPack.pid = 0;    /* must set this later */
@@ -124,9 +124,9 @@ int init_uptime(void)
   uptimecount = 0;
   uptimeip = -1;
 
-  strncpyz(temp, ver, sizeof temp);
-  splitc(uptime_version, temp, ' ');
-  strncpyz(uptime_version, temp, sizeof uptime_version);
+  strncpyz(x, ver, sizeof x);
+  newsplit(&z);
+  strncpyz(uptime_version, z, sizeof uptime_version);
 
   if ((uptimesock = socket(AF_INET, SOCK_DGRAM, 0)) < 0) {
     putlog(LOG_DEBUG, "*", "init_uptime socket returned < 0 %d", uptimesock);
