@@ -4,11 +4,11 @@
  *   Tcl initialization
  *   getting and setting Tcl/eggdrop variables
  *
- * $Id: tcl.c,v 1.81 2004/07/25 11:17:34 wcc Exp $
+ * $Id: tcl.c,v 1.86 2006-03-28 02:35:50 wcc Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004 Eggheads Development Team
+ * Copyright (C) 1999 - 2006 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -51,7 +51,7 @@ extern char origbotname[], botuser[], motdfile[], admin[], userfile[],
             egg_version[], natip[], configfile[], logfile_suffix[], textdir[],
             pid_file[];
 
-extern int backgrd, flood_telnet_thr, flood_telnet_time, shtime, share_greet,
+extern int flood_telnet_thr, flood_telnet_time, shtime, share_greet,
            require_p, keep_all_logs, allow_new_telnets, stealth_telnets,
            use_telnet_banner, default_flags, conmask, switch_logfiles_at,
            connect_timeout, firewallport, notify_users_at, flood_thr, tands,
@@ -100,16 +100,6 @@ int expmem_tcl()
   return strtot + utftot + clientdata_stuff;
 }
 
-int findidx(int z)
-{
-  int j;
-
-  for (j = 0; j < dcc_total; j++)
-    if ((dcc[j].sock == z) && (dcc[j].type->flags & DCT_VALIDIDX))
-      return j;
-  return -1;
-}
-
 static void botnet_change(char *new)
 {
   if (egg_strcasecmp(botnetnick, new)) {
@@ -140,6 +130,10 @@ typedef struct {
   int *right; /* right side */
 } coupletinfo;
 
+/* FIXME: tcl_eggcouplet() should be redesigned so we can use
+ * TCL_TRACE_WRITES | TCL_TRACE_READS as the bit mask instead
+ * of 2 calls as is done in add_tcl_coups().
+ */
 /* Read/write integer couplets (int1:int2) */
 static char *tcl_eggcouplet(ClientData cdata, Tcl_Interp *irp,
                             EGG_CONST char *name1,
@@ -329,7 +323,6 @@ static char *tcl_eggstr(ClientData cdata, Tcl_Interp *irp,
  */
 
 #ifdef USE_TCL_BYTE_ARRAYS
-
 static int utf_converter(ClientData cdata, Tcl_Interp *myinterp, int objc,
                          Tcl_Obj *CONST objv[])
 {
@@ -369,7 +362,9 @@ void cmd_delete_callback(ClientData cdata)
   nfree(cdata);
   clientdata_stuff -= sizeof(void *) * 2;
 }
+#endif /* USE_TCL_BYTE_ARRAYS */
 
+#ifdef USE_TCL_BYTE_ARRAYS
 void add_tcl_commands(tcl_cmds *table)
 {
   void **cdata;
@@ -385,6 +380,18 @@ void add_tcl_commands(tcl_cmds *table)
   }
 }
 
+#else /* USE_TCL_BYTE_ARRAYS */
+
+void add_tcl_commands(tcl_cmds *table)
+{
+  int i;
+
+  for (i = 0; table[i].name; i++)
+    Tcl_CreateCommand(interp, table[i].name, table[i].func, NULL, NULL);
+}
+#endif /* USE_TCL_BYTE_ARRAYS */
+
+#ifdef USE_TCL_BYTE_ARRAYS
 void add_cd_tcl_cmds(cd_tcl_cmd *table)
 {
   void **cdata;
@@ -402,14 +409,6 @@ void add_cd_tcl_cmds(cd_tcl_cmd *table)
 
 #else /* USE_TCL_BYTE_ARRAYS */
 
-void add_tcl_commands(tcl_cmds *table)
-{
-  int i;
-
-  for (i = 0; table[i].name; i++)
-    Tcl_CreateCommand(interp, table[i].name, table[i].func, NULL, NULL);
-}
-
 void add_cd_tcl_cmds(cd_tcl_cmd *table)
 {
   while (table->name) {
@@ -418,7 +417,6 @@ void add_cd_tcl_cmds(cd_tcl_cmd *table)
     table++;
   }
 }
-
 #endif /* USE_TCL_BYTE_ARRAYS */
 
 void rem_tcl_commands(tcl_cmds *table)
@@ -437,16 +435,16 @@ void rem_cd_tcl_cmds(cd_tcl_cmd *table)
   }
 }
 
+#ifdef USE_TCL_OBJ
 void add_tcl_objcommands(tcl_cmds *table)
 {
-#ifdef USE_TCL_OBJ
   int i;
 
   for (i = 0; table[i].name; i++)
     Tcl_CreateObjCommand(interp, table[i].name, table[i].func, (ClientData) 0,
                          NULL);
-#endif /* USE_TCL_OBJ */
 }
+#endif
 
 static tcl_strings def_tcl_strings[] = {
   {"botnet-nick",     botnetnick,     HANDLEN,                 0},
@@ -687,7 +685,9 @@ resetPath:
   add_tcl_commands(tcluser_cmds);
   add_tcl_commands(tcldcc_cmds);
   add_tcl_commands(tclmisc_cmds);
+#ifdef USE_TCL_OBJ
   add_tcl_objcommands(tclmisc_objcmds);
+#endif
   add_tcl_commands(tcldns_cmds);
 }
 
@@ -695,7 +695,6 @@ void do_tcl(char *whatzit, char *script)
 {
   int code;
   char *result;
-
 #ifdef USE_TCL_ENCODING
   Tcl_DString dstr;
 #endif
